@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2ODRF import H2ODRF
 
@@ -42,7 +42,6 @@ class H2ODRFClassifier(H2ODRF):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  mtries=-1,
                  binomialDoubleTrees=False,
                  sampleRate=0.632,
@@ -65,6 +64,7 @@ class H2ODRFClassifier(H2ODRF):
                  minSplitImprovement=1.0E-5,
                  histogramType="AUTO",
                  calibrateModel=False,
+                 calibrationMethod="AUTO",
                  checkConstantResponse=True,
                  modelId=None,
                  nfolds=0,
