@@ -279,18 +279,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Controls the effect of observations with positive labels in relation to the observations with negative labels on gradient calculation. Useful for imbalanced problems.""",
         H2OTypeConverters.toFloat())
 
-    evalMetric = Param(
-        Params._dummy(),
-        "evalMetric",
-        """Specification of evaluation metric that will be passed to the native XGBoost backend.""",
-        H2OTypeConverters.toNullableString())
-
-    scoreEvalMetricOnly = Param(
-        Params._dummy(),
-        "scoreEvalMetricOnly",
-        """If enabled, score only the evaluation metric. This can make model training faster if scoring is frequent (eg. each iteration).""",
-        H2OTypeConverters.toBoolean())
-
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -321,12 +309,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Whether to keep the cross-validation fold assignment.""",
         H2OTypeConverters.toBoolean())
 
-    parallelizeCrossValidation = Param(
-        Params._dummy(),
-        "parallelizeCrossValidation",
-        """Allow parallel training of cross-validation models""",
-        H2OTypeConverters.toBoolean())
-
     distribution = Param(
         Params._dummy(),
         "distribution",
@@ -558,12 +540,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getScalePosWeight(self):
         return self.getOrDefault(self.scalePosWeight)
 
-    def getEvalMetric(self):
-        return self.getOrDefault(self.evalMetric)
-
-    def getScoreEvalMetricOnly(self):
-        return self.getOrDefault(self.scoreEvalMetricOnly)
-
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -579,9 +555,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getKeepCrossValidationFoldAssignment(self):
         return self.getOrDefault(self.keepCrossValidationFoldAssignment)
 
-    def getParallelizeCrossValidation(self):
-        return self.getOrDefault(self.parallelizeCrossValidation)
-
     def getDistribution(self):
         return self.getOrDefault(self.distribution)
 
@@ -762,12 +735,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setScalePosWeight(self, value):
         return self._set(scalePosWeight=value)
 
-    def setEvalMetric(self, value):
-        return self._set(evalMetric=value)
-
-    def setScoreEvalMetricOnly(self, value):
-        return self._set(scoreEvalMetricOnly=value)
-
     def setModelId(self, value):
         return self._set(modelId=value)
 
@@ -783,9 +750,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setKeepCrossValidationFoldAssignment(self, value):
         return self._set(keepCrossValidationFoldAssignment=value)
 
-    def setParallelizeCrossValidation(self, value):
-        return self._set(parallelizeCrossValidation=value)
-
     def setDistribution(self, value):
         return self._set(distribution=value)
 
