@@ -16,7 +16,7 @@ from h2o.exceptions import H2OValueError, H2OResponseError
 from h2o.frame import H2OFrame
 from h2o.job import H2OJob
 from h2o.utils.mixin import assign, load_ext, mixin
-from h2o.utils.shared_utils import quoted
+from h2o.utils.shared_utils import quoted, LookupSeq
 from h2o.utils.typechecks import assert_is_type, is_type, numeric, FunctionType
 from h2o.model import ModelBase, H2OSegmentModels
 from h2o.model.models import *
@@ -227,7 +227,7 @@ class H2OEstimator(ModelBase):
         if verbose and not self._options_.get('verbose', False):
             raise H2OValueError("Verbose mode is not available for %s" % self.__class__.__name__)
         parms = self._parms.copy()
-        names = training_frame.names if training_frame is not None else []
+        names = LookupSeq(training_frame.names if training_frame is not None else [])
         ncols = training_frame.ncols if training_frame is not None else 0
         types = training_frame.types if training_frame is not None else {}
     
@@ -266,7 +266,7 @@ class H2OEstimator(ModelBase):
                             raise H2OValueError("Column %s not in the training frame" % ic)
                         ignored_columns_set.add(ic)
             if x is None:
-                xset = set(names) - {y} - ignored_columns_set
+                xset = names.set() - {y} - ignored_columns_set
             elif isinstance(x, ModelBase) and hasattr(x, '_extract_x_from_model'):
                 xset = x._extract_x_from_model()
             else:
@@ -309,8 +309,8 @@ class H2OEstimator(ModelBase):
         if len(x) > 0 and is_type(x[0], int):
             x = [names[i] for i in x]
         if override_default_training_frame:
-            ignored_columns = list(set(names) - set(x + [y, offset, folds, weights]))
-            parms["ignored_columns"] = None if ignored_columns == [] else [quoted(col) for col in ignored_columns]
+            ignored_columns = list(names.set() - set(x + [y, offset, folds, weights]))
+            parms["ignored_columns"] = None if len(ignored_columns) == 0 else [quoted(col) for col in ignored_columns]
         parms["interactions"] = (None if "interactions" not in parms or parms["interactions"] is None
                                  else [quoted(col) for col in parms["interactions"]])
         parms["interaction_pairs"] = (None if "interaction_pairs" not in parms or parms["interaction_pairs"] is None
